@@ -41,11 +41,12 @@ from .templates.CodeTemplatesContraction import *
 
 from .templates.CodeTemplatesParameterParsing import *
 
-from .templates.CodeTemplatesAssignments import *
 from .templates.CodeTemplatesExceptions import *
 from .templates.CodeTemplatesImporting import *
 from .templates.CodeTemplatesPrinting import *
 from .templates.CodeTemplatesTuples import *
+from .templates.CodeTemplatesLists import *
+from .templates.CodeTemplatesDicts import *
 from .templates.CodeTemplatesCalls import *
 from .templates.CodeTemplatesClass import *
 from .templates.CodeTemplatesLoops import *
