@@ -34,6 +34,7 @@ from .Identifiers import (
     Identifier,
     ConstantIdentifier,
     TempObjectIdentifier,
+    TempVariableIdentifier,
     LocalVariableIdentifier,
     ClosureVariableIdentifier
 )
@@ -86,9 +87,12 @@ class PythonContextBase:
     def needsFrameExceptionKeeper( self ):
         return False
 
-    def getTempHandle( self, var_name ):
+    def getTempObjectHandle( self, var_name ):
         return TempObjectIdentifier( var_name, from_context = "" )
 
+    def getTempVarHandle( self, var_name ):
+        return TempVariableIdentifier( var_name )
+
 
 class PythonChildContextBase( PythonContextBase ):
     def __init__( self, parent ):
@@ -102,6 +106,12 @@ class PythonChildContextBase( PythonContextBase ):
     def addMakeTupleUse( self, value ):
         self.parent.addMakeTupleUse( value )
 
+    def addMakeListUse( self, value ):
+        self.parent.addMakeListUse( value )
+
+    def addMakeDictUse( self, value ):
+        self.parent.addMakeDictUse( value )
+
     def getParent( self ):
         return self.parent
 
@@ -172,8 +182,11 @@ class PythonGlobalContext:
 
         # Have EVAL_ORDER for 1..6 in any case, so we can use it in the C++ code freely
         # without concern.
-        self.eval_orders_used = set( range( 1, 6 ) )
         self.make_tuples_used = set( range( 1, 6 ) )
+        self.make_lists_used = set( range( 0, 1 ) )
+        self.make_dicts_used = set( range( 0, 3 ) )
+
+        self.eval_orders_used = set( range( 0, 6 ) )
 
     def getConstantHandle( self, constant ):
         if constant is None:
@@ -209,9 +222,27 @@ class PythonGlobalContext:
         self.addEvalOrderUse( value ) # generated code uses it
         self.make_tuples_used.add( value )
 
+    def addMakeListUse( self, value ):
+        assert type( value ) is int
+
+        self.addEvalOrderUse( value ) # generated code uses it
+        self.make_lists_used.add( value )
+
+    def addMakeDictUse( self, value ):
+        assert type( value ) is int
+
+        self.addEvalOrderUse( value * 2 ) # generated code uses it
+        self.make_dicts_used.add( value )
+
     def getMakeTuplesUsed( self ):
         return sorted( self.make_tuples_used )
 
+    def getMakeListsUsed( self ):
+        return sorted( self.make_lists_used )
+
+    def getMakeDictsUsed( self ):
+        return sorted( self.make_dicts_used )
+
 
 class PythonModuleContext( PythonContextBase ):
     # Plent of attributes, because it's storing so many different things.
@@ -313,6 +344,12 @@ class PythonModuleContext( PythonContextBase ):
     def addMakeTupleUse( self, value ):
         self.global_context.addMakeTupleUse( value )
 
+    def addMakeListUse( self, value ):
+        self.global_context.addMakeListUse( value )
+
+    def addMakeDictUse( self, value ):
+        self.global_context.addMakeDictUse( value )
+
 
 class PythonFunctionContext( PythonChildContextBase ):
     def __init__( self, parent, function ):
@@ -360,7 +397,7 @@ class PythonFunctionContext( PythonChildContextBase ):
         else:
             return ClosureVariableIdentifier( var_name, from_context = "_python_context->common_context->" )
 
-    def getTempHandle( self, var_name ):
+    def getTempObjectHandle( self, var_name ):
         if self.function.isGenerator():
             return TempObjectIdentifier( var_name, from_context = "_python_context->" )
         else:
@@ -428,7 +465,7 @@ class PythonGeneratorExpressionContext( PythonContractionBase ):
     def getLocalHandle( self, var_name ):
         return LocalVariableIdentifier( var_name, from_context = True )
 
-    def getTempHandle( self, var_name ):
+    def getTempObjectHandle( self, var_name ):
         return TempObjectIdentifier( var_name, from_context = "_python_context->" )
 
     def hasFrameGuard( self ):
