@@ -33,39 +33,34 @@ These are mostly used to look up the Python C/API from operations or a wrapper u
 """
 
 binary_operator_codes = {
-    "Add"      : "PyNumber_Add",
-    "Sub"      : "PyNumber_Subtract",
-    "Pow"      : "PyNumber_Power",
-    "Mult"     : "PyNumber_Multiply",
-    "Div"      : "PyNumber_Divide",
-    "FloorDiv" : "PyNumber_FloorDivide",
-    "TrueDiv"  : "PyNumber_TrueDivide",
-    "Mod"      : "PyNumber_Remainder",
-    "LShift"   : "PyNumber_Lshift",
-    "RShift"   : "PyNumber_Rshift",
-    "BitAnd"   : "PyNumber_And",
-    "BitOr"    : "PyNumber_Or",
-    "BitXor"   : "PyNumber_Xor",
+    "Add"       : "PyNumber_Add",
+    "Sub"       : "PyNumber_Subtract",
+    "Pow"       : "PyNumber_Power",
+    "Mult"      : "PyNumber_Multiply",
+    "Div"       : "PyNumber_Divide",
+    "FloorDiv"  : "PyNumber_FloorDivide",
+    "TrueDiv"   : "PyNumber_TrueDivide",
+    "Mod"       : "PyNumber_Remainder",
+    "LShift"    : "PyNumber_Lshift",
+    "RShift"    : "PyNumber_Rshift",
+    "BitAnd"    : "PyNumber_And",
+    "BitOr"     : "PyNumber_Or",
+    "BitXor"    : "PyNumber_Xor",
+    "IAdd"      : "PyNumber_InPlaceAdd",
+    "ISub"      : "PyNumber_InPlaceSubtract",
+    "IPow"      : "PyNumber_InPlacePower",
+    "IMult"     : "PyNumber_InPlaceMultiply",
+    "IDiv"      : "PyNumber_InPlaceDivide",
+    "IFloorDiv" : "PyNumber_InPlaceFloorDivide",
+    "ITrueDiv"  : "PyNumber_InPlaceTrueDivide",
+    "IMod"      : "PyNumber_InPlaceRemainder",
+    "ILShift"   : "PyNumber_InPlaceLshift",
+    "IRShift"   : "PyNumber_InPlaceRshift",
+    "IBitAnd"   : "PyNumber_InPlaceAnd",
+    "IBitOr"    : "PyNumber_InPlaceOr",
+    "IBitXor"   : "PyNumber_InPlaceXor",
 }
 
-inplace_operator_codes = {
-    "Add"      : "PyNumber_InPlaceAdd",
-    "Sub"      : "PyNumber_InPlaceSubtract",
-    "Pow"      : "PyNumber_InPlacePower",
-    "Mult"     : "PyNumber_InPlaceMultiply",
-    "Div"      : "PyNumber_InPlaceDivide",
-    "FloorDiv" : "PyNumber_InPlaceFloorDivide",
-    "TrueDiv"  : "PyNumber_InPlaceTrueDivide",
-    "Mod"      : "PyNumber_InPlaceRemainder",
-    "LShift"   : "PyNumber_InPlaceLshift",
-    "RShift"   : "PyNumber_InPlaceRshift",
-    "BitAnd"   : "PyNumber_InPlaceAnd",
-    "BitOr"    : "PyNumber_InPlaceOr",
-    "BitXor"   : "PyNumber_InPlaceXor",
-}
-
-assert inplace_operator_codes.keys() == binary_operator_codes.keys()
-
 unary_operator_codes = {
     "UAdd"   : ( "PyNumber_Positive", 1 ),
     "USub"   : ( "PyNumber_Negative", 1 ),
