@@ -74,9 +74,6 @@ static PyObject *_MAKE_FUNCTION_%(function_identifier)s( %(function_creation_arg
         _context_%(function_identifier)s_destructor
     );
 
-    // Apply decorators if any
-%(function_decorator_calls)s
-
     return result;
 }
 """
@@ -94,9 +91,6 @@ static PyObject *_MAKE_FUNCTION_%(function_identifier)s( %(function_creation_arg
         %(function_doc)s
     );
 
-    // Apply decorators if any
-%(function_decorator_calls)s
-
     return result;
 }
 """
